package Bundle::Locale::CLDR::Westernasia;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::Westernasia

=head1 CONTENTS

Locale::CLDR::Locales::Ar 0.34.1
Locale::CLDR::Locales::Az 0.34.1
Locale::CLDR::Locales::El 0.34.1
Locale::CLDR::Locales::Fr 0.34.1
Locale::CLDR::Locales::He 0.34.1
Locale::CLDR::Locales::Hy 0.34.1
Locale::CLDR::Locales::Ka 0.34.1
Locale::CLDR::Locales::Ku 0.34.1
Locale::CLDR::Locales::Os 0.34.1
Locale::CLDR::Locales::Tr 0.34.1
Locale::CLDR::Locales::Ckb 0.34.1
Locale::CLDR::Locales::Lrc 0.34.1
Locale::CLDR::Locales::Ar::Any 0.34.1
Locale::CLDR::Locales::El::Any 0.34.1
Locale::CLDR::Locales::En::Any 0.34.1
Locale::CLDR::Locales::Fr::Any 0.34.1
Locale::CLDR::Locales::He::Any 0.34.1
Locale::CLDR::Locales::Hy::Any 0.34.1
Locale::CLDR::Locales::Ka::Any 0.34.1
Locale::CLDR::Locales::Ku::Any 0.34.1
Locale::CLDR::Locales::Os::Any 0.34.1
Locale::CLDR::Locales::Tr::Any 0.34.1
Locale::CLDR::Locales::Az::Cyrl 0.34.1
Locale::CLDR::Locales::Az::Latn 0.34.1
Locale::CLDR::Locales::Ckb::Any 0.34.1
Locale::CLDR::Locales::Lrc::Any 0.34.1
Locale::CLDR::Locales::Ar::Any::Ae 0.34.1
Locale::CLDR::Locales::Ar::Any::Bh 0.34.1
Locale::CLDR::Locales::Ar::Any::Il 0.34.1
Locale::CLDR::Locales::Ar::Any::Iq 0.34.1
Locale::CLDR::Locales::Ar::Any::Jo 0.34.1
Locale::CLDR::Locales::Ar::Any::Kw 0.34.1
Locale::CLDR::Locales::Ar::Any::Lb 0.34.1
Locale::CLDR::Locales::Ar::Any::Om 0.34.1
Locale::CLDR::Locales::Ar::Any::Ps 0.34.1
Locale::CLDR::Locales::Ar::Any::Qa 0.34.1
Locale::CLDR::Locales::Ar::Any::Sa 0.34.1
Locale::CLDR::Locales::Ar::Any::Sy 0.34.1
Locale::CLDR::Locales::Ar::Any::Ye 0.34.1
Locale::CLDR::Locales::El::Any::Cy 0.34.1
Locale::CLDR::Locales::En::Any::Cy 0.34.1
Locale::CLDR::Locales::En::Any::Il 0.34.1
Locale::CLDR::Locales::Fr::Any::Sy 0.34.1
Locale::CLDR::Locales::He::Any::Il 0.34.1
Locale::CLDR::Locales::Hy::Any::Am 0.34.1
Locale::CLDR::Locales::Ka::Any::Ge 0.34.1
Locale::CLDR::Locales::Ku::Any::Tr 0.34.1
Locale::CLDR::Locales::Os::Any::Ge 0.34.1
Locale::CLDR::Locales::Tr::Any::Cy 0.34.1
Locale::CLDR::Locales::Tr::Any::Tr 0.34.1
Locale::CLDR::Locales::Az::Cyrl::Az 0.34.1
Locale::CLDR::Locales::Az::Latn::Az 0.34.1
Locale::CLDR::Locales::Ckb::Any::Iq 0.34.1
Locale::CLDR::Locales::En::Any::001 0.34.1
Locale::CLDR::Locales::Lrc::Any::Iq 0.34.1

=cut

1;

